@@ -1,6 +1,6 @@
 "Krig.find.gcvmin" <-
-function (info, lambda.grid, gcv, gcv.fun, tol, verbose = FALSE,
-give.warnings=TRUE) 
+function (info, lambda.grid, gcv, gcv.fun, tol, verbose = FALSE, 
+    give.warnings = TRUE) 
 {
     ind <- !is.na(gcv)
     lambda.grid <- lambda.grid[ind]
@@ -10,8 +10,10 @@ give.warnings=TRUE)
     lambda.gcv <- lambda.grid[il]
     gcv.raw <- min(gcv)
     if (verbose) {
-        cat("Results of coarse search lambda and GCV:", 
-lambda.grid[il],gcv.raw, fill=TRUE)
+        cat( "#### Call for refined search using", 
+               as.character(substitute( gcv.fun)), fill=TRUE)
+        cat("Results of coarse search lambda and GCV:", lambda.grid[il], 
+            gcv.raw, fill = TRUE)
     }
     if ((il > 1) & (il < nstep.cv)) {
         out <- golden.section.search(lambda.grid[il - 1], lambda.grid[il], 
@@ -20,8 +22,10 @@ lambda.grid[il],gcv.raw, fill=TRUE)
         return(out$x)
     }
     else {
-        if( give.warnings){
-         warning("GCV search gives a minumum at the endpoints of the grid search")}
+        if (give.warnings) {
+            warning("GCV search gives a minumum at the endpoints of the grid search")
+        }
         return(lambda.gcv)
     }
 }
+
