@@ -16,7 +16,7 @@ function (x1, x2, C, p = 1, with.log = TRUE, with.constant = TRUE)
     temp <- .Fortran("multrb", nd = as.integer(d), x1 = as.double(x1), 
         n1 = as.integer(n1), x2 = as.double(x2), n2 = as.integer(n2), 
         par = as.double(par), c = as.double(C), h = as.double(rep(0, 
-            n1)), work = as.double(rep(0, n2)))
+            n1)), work = as.double(rep(0, n2)), PACKAGE="fields")
     if (with.constant) {
         m <- (d + p)/2
         Amd <- radbas.constant(m, d)
